import javax.swing.JOptionPane;

/**
 * This class provides methods for reading integers, floating-point
 * numbers and strings via simple GUI dialogue boxes.
 * Remember to stop all execution by using this statement in your program:
 *   System.exit(0);
 */
public final class GUIDialog {
  private GUIDialog() { };  // Cannot create objects of this class.

  /**
   * Reads an int value.
   * @return An int value
   */
  public static int requestInt(Object prompt) {                     //(1)
    String input = "";
    while (true)                                                    //(2)
      try {
        input = JOptionPane.showInputDialog(null, prompt, "Input",  //(3)
                                            JOptionPane.PLAIN_MESSAGE);
        return Integer.parseInt(input);                             //(4)
      } catch (NullPointerException exception) {                    //(5)
          prompt("\"" + input + "\"" + " is not a valid integer.");
      } catch (NumberFormatException exception) {                   //(6)
          prompt("\"" + input + "\"" + " is not a valid integer.");
      }
  }

  /**
   * Reads a double value.
   * @return A double value
   */
  public static double requestDouble(Object prompt) {               //(7)
    String input = "";
    while (true)
      try {
        input = JOptionPane.showInputDialog(null, prompt, "Input",
                                            JOptionPane.PLAIN_MESSAGE);
        return Double.parseDouble(input);
      } catch (NullPointerException exception) {
          prompt("\"" + input + "\"" +
                 " is not a valid floating-point number.");
      } catch (NumberFormatException exception) {
          prompt("\"" + input + "\"" +
                 " is not a valid floating-point number.");
      }
  }

  /**
   * Reads a non-empty string.
   * @return A string
   */
  public static String requestString(Object prompt) {               //(8)
    String input = "";
    while (true)
      try {
        input = JOptionPane.showInputDialog(null, prompt, "Input",
                                            JOptionPane.PLAIN_MESSAGE);
        if (input == null || input.length() == 0) {
          throw new IllegalArgumentException();
        }
        return input;
      } catch (IllegalArgumentException exception) {
          prompt("\"" + input + "\"" + " is not a valid string.");
      }
  }

  /**
   * Prints a message.
   */
  public static void prompt(Object message) {                       //(9)
    JOptionPane.showMessageDialog(null, message, "Message",
                                  JOptionPane.WARNING_MESSAGE);
  }

  // Return values from the method confirm()
  public static final int YES = JOptionPane.YES_OPTION;
  public static final int NO = JOptionPane.NO_OPTION;
  public static final int CANCEL = JOptionPane.CANCEL_OPTION;

  /**
   * Confirms information.
   * @return YES, if YES button was clicked.
   * @return NO, if NO button was clicked.
   * @return CANCEL, if CANCEL button was clicked.
   */
  public static int confirmInfo(Object information) {               //(10)
    return JOptionPane.showConfirmDialog(null, information, "Confirm",
                                         JOptionPane.YES_NO_CANCEL_OPTION);
  }
}