// Personnel register of employees
class PersonnelRegister {                                          // (2)

  final static int MAX_NUM_EMPLOYEES = 100;

  // Fields
  Employee[] employees;
  int      numOfEmployees;
  int      numOfFemales;

  // Default constructor
  PersonnelRegister() {
    employees = new Employee[MAX_NUM_EMPLOYEES];
  }

  // Create a personnel register from an array of employees.
  PersonnelRegister(Employee[] suppliedEmployeeArray) {
    employees = new Employee[MAX_NUM_EMPLOYEES];
    for( int i = 0; i < suppliedEmployeeArray.length; i++) {
      registerEmployee(suppliedEmployeeArray[i]);
    }
  }

  // Create a personnel register with field values from parameters.
  PersonnelRegister(Employee[] employees, int numOfEmployees,
                           int numOfFemales) {
    this.employees = employees;
    this.numOfEmployees = numOfEmployees;
    this.numOfFemales = numOfFemales;
  }

  // Register an employee in the employee array.
  void registerEmployee(Employee newEmployee) {
    assert numOfEmployees != employees.length:
           "No room for more employees.";
    employees[numOfEmployees] = newEmployee;
    numOfEmployees++;
    if (newEmployee.gender == Gender.FEMALE) {
      numOfFemales++;
    }
  }

  // Selectors
  int getNumOfEmployees()       { return numOfEmployees; }
  int getNumOfFemales()         { return numOfFemales; }
  Employee[] getEmployeeArray() { return employees; }

  // Return employee with specified index.
  Employee getEmployee(int index) {
    assert 0 <= index && index <= numOfEmployees :
           "Index not valid";
    return employees[index];
  }

  // Replace an employee at index with another employee.
  void replaceEmployee(int index, Employee newEmployee) {
    assert 0 <= index && index <= numOfEmployees :
           "Index not valid";
    employees[index] = newEmployee;
  }

  // Compute percentage of females in the company.
  double getFemalePercentage() {
    assert numOfEmployees > 0 : "Personnel register is empty.";
    return 100.0 * numOfFemales / numOfEmployees;
  }

  // Returns statistics about the company.
  public String toString() {
    return String.format("The company has %d employees," +
                         " where %.2f%% are women.",
                          getNumOfEmployees(), getFemalePercentage());
  }
}